@@ -1,9 +1,10 @@
-from .client import WebsetsClient
+from .client import WebsetsClient, AsyncWebsetsClient
 from .imports import ImportsClient
 from .events import EventsClient
 
 __all__ = [
     "WebsetsClient",
+    "AsyncWebsetsClient", 
     "ImportsClient",
     "EventsClient",
 ] 
\ No newline at end of file
